@@ -203,7 +203,7 @@ EWAPI const Efl_Class *efl_net_control_access_point_class_get(void);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Future *efl_net_control_access_point_connect(Eo *obj);
+EOAPI Eina_Future *efl_net_control_access_point_connect(Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Disconnects from this access point.
@@ -436,7 +436,7 @@ EOAPI Efl_Net_Control_Access_Point_Security efl_net_control_access_point_securit
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief NTP (Time Server) in use for this access point.
@@ -451,7 +451,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Searches domains in use for this access point.
@@ -466,7 +466,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief IPv4 in use for this access point.
@@ -524,7 +524,7 @@ EOAPI void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes);
+EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief DNS (Domain Name Servers) configured by user for this access point.
@@ -539,7 +539,7 @@ EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj, Eina_Iterator *name_servers);
+EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj, Eina_Iterator *name_servers EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief DNS (Domain Name Servers) configured by user for this access point.
@@ -555,7 +555,7 @@ EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj,
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief NTP (Time Server) configured by user for this access point.
@@ -570,7 +570,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj, Eina_Iterator *time_servers);
+EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj, Eina_Iterator *time_servers EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief NTP (Time Server) configured by user for this access point.
@@ -586,7 +586,7 @@ EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj,
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief Searches domains configured by user for this access point.
@@ -601,7 +601,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_Iterator *domains);
+EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_Iterator *domains EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief Searches domains configured by user for this access point.
@@ -617,7 +617,7 @@ EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_domains_get(const Eo *obj);
+EOAPI Eina_Iterator *efl_net_control_access_point_configuration_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 
 /**
  * @brief IPv4 configured by user for this access point.
@@ -715,7 +715,7 @@ EOAPI void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Ef
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method method, const char *url, Eina_Iterator *servers, Eina_Iterator *excludes);
+EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method method, const char *url, Eina_Iterator *servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator *excludes EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief Proxy configured by user for this access point.
@@ -739,7 +739,7 @@ EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes);
+EOAPI void efl_net_control_access_point_configuration_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
 
 EWAPI extern const Efl_Event_Description _EFL_NET_CONTROL_ACCESS_POINT_EVENT_CHANGED;
 
