@@ -6,11 +6,12 @@
  * as desired
  */
 #ifndef EFL_API_OVERRIDE 
-
+#define EFL_API_LEGACY_DEF "FIXME NOT IMPLEMENTED"
 #endif
 
 #define EFL_VERSION_MAJOR 1
-#define EFL_VERSION_MINOR 22
+#define EFL_VERSION_MINOR 23
+#define EFL_VERSION_MICRO 3
 #define EFL_BUILD_ID "none"
 
 #endif
