@@ -13,8 +13,18 @@ typedef Eo Efl_Ui_Slider;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
-/** Elementary slider class
+/**
+ * @brief Elementary slider class
+ *
+ * This lets the UI user select a numerical value inside the
+ * @ref efl_ui_range_limits_get limits. The current value can be retrieved
+ * using the @ref Efl_Ui_Range_Interactive interface. Events monitoring its
+ * changes are also available in that interface. The visual representation of
+ * min and max can be swapped using @ref efl_ui_layout_orientation_get.
+ * Normally the minimum of @ref efl_ui_range_limits_get is shown on the left
+ * side, the max on the right side.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Slider
  */
@@ -22,25 +32,12 @@ typedef Eo Efl_Ui_Slider;
 
 EWAPI const Efl_Class *efl_ui_slider_class_get(void);
 
-EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_EVENT_CHANGED;
-
-/** Called when slider changed
- *
- * @ingroup Efl_Ui_Slider
- */
-#define EFL_UI_SLIDER_EVENT_CHANGED (&(_EFL_UI_SLIDER_EVENT_CHANGED))
-
-EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_EVENT_DELAY_CHANGED;
-
-/** Called when delay changed
- *
- * @ingroup Efl_Ui_Slider
- */
-#define EFL_UI_SLIDER_EVENT_DELAY_CHANGED (&(_EFL_UI_SLIDER_EVENT_DELAY_CHANGED))
-
 EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_EVENT_SLIDER_DRAG_START;
 
-/** Called when slider drag started
+/** Called when a slider drag operation has started. This means a @c press
+ * event has been received on the slider thumb but not the @c unpress.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Slider
  */
@@ -48,11 +45,13 @@ EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_EVENT_SLIDER_DRAG_START;
 
 EWAPI extern const Efl_Event_Description _EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP;
 
-/** Called when slider drag stopped
+/** Called when a slider drag operation has finished. This means an @c unpress
+ * event has been received on the slider thumb.
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Slider
  */
 #define EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP (&(_EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP))
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
